var fb = require('../'),
    url = require('url'),
    assert = require('assert');

// Fake client.request method.
var ACCESS_TOKEN = '117743971608120|2.vdCKd4ZIEJlHwwtrkilgKQ__.86400.1281049200-1677846385|NF_2DDNxFBznj2CuwiwabHhTAHc.';


var testClient1 = fb.createClient(ACCESS_TOKEN);


/**
 * Fake the request triggering the callback with the inputed options.
 *
 * @see Client.prototype._request in index.js
**/
testClient1._request = function(options, cb) {
  cb(false, options);
};


module.exports = {
  'test: createClient(ACCESS_TOKEN)': function() {
    var client = fb.createClient(ACCESS_TOKEN);

    assert.equal('graph.facebook.com', client.host);
    assert.equal(ACCESS_TOKEN, client.access_token);
    assert.ok(client instanceof fb.Client);
  },

  'test: getObject(1234)': function(done) {
    testClient1.getObject(1234, function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/1234', rurl.pathname);
      assert.equal(ACCESS_TOKEN, rurl.query.access_token);
      assert.equal('graph.facebook.com', rurl.hostname);
      assert.equal('https:', rurl.protocol);
      done();
    });
  },

  'test: getObject(1234, {fields: ["id", "name", "link"]})': function(done) {
    testClient1.getObject(1234, {
      fields: ['id', 'name', 'link']
    }, function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/1234', rurl.pathname);
      assert.equal('id,name,link', rurl.query.fields);
      done();
    });
  },

  'test: getObjects([1234, 5678, 9012])': function(done) {
    testClient1.getObjects([1234, 5678, 9012], function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/', rurl.pathname);
      assert.equal('1234,5678,9012', rurl.query.ids);
      done();
    });
  },

  'test: getObjects([1234, 5678, 9012], {fields: ["id", "name", "link"]})': function(done) {
    testClient1.getObjects([1234, 5678, 9012], {
      fields: ['id', 'name', 'link']
    }, function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/', rurl.pathname);
      assert.equal('1234,5678,9012', rurl.query.ids);
      assert.equal('id,name,link', rurl.query.fields);
      done();
    });
  },

  'test: getConnection("me", "feed")': function(done) {
    testClient1.getConnection('me', 'feed', function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/me/feed', rurl.pathname);
      assert.deepEqual({access_token: ACCESS_TOKEN}, rurl.query);
      done();
    });
  },

  'test: getConnection("me", "feed", {limit: 1})': function(done) {
    testClient1.getConnection('me', 'feed', {
      limit: 1
    }, function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/me/feed', rurl.pathname);
      assert.deepEqual({access_token: ACCESS_TOKEN, limit: 1}, rurl.query);
      done();
    });
  },

  'test: getConnection("me", "feed", {limit: 1, access_token: "foo"})': function(done) {
    testClient1.getConnection('me', 'feed', {
      limit: 1,
      access_token: 'foo'
    }, function(err, options) {
      var rurl = url.parse(options.uri, true);
      assert.equal('GET', options.method);
      assert.equal('/me/feed', rurl.pathname);
      assert.equal('foo', rurl.query.access_token);
      assert.notEqual(ACCESS_TOKEN, rurl.query.access_token);
      done();
    });
  }
};
